@@ -15,12 +15,14 @@ static PyObject* xor(PyObject* self, PyObject* args) {
   char* result = malloc(source_len);
   Py_ssize_t si = 0;
   Py_ssize_t ci = 0;
+  Py_BEGIN_ALLOW_THREADS
   for (; si < source_len; si ++, ci ++) {
     if (ci == code_len) {
       ci = 0;
     }
     result[si] = source[si] ^ code[ci];
   }
+  Py_END_ALLOW_THREADS
   PyObject* res = Py_BuildValue("s#", result, source_len);
   free(result);
   result = NULL;
